PaymentMethod

Enum PaymentMethod 

#[non_exhaustive]
pub enum PaymentMethod { Card(CardPaymentMethod), Stablecoin(StablecoinPaymentMethod), Crypto(CryptoPaymentMethod), PayPal(PayPalPaymentMethod), MobileMoney(MobileMoneyPaymentMethod), }
Provider-neutral payment method.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Card(CardPaymentMethod)

Card payment.



Stablecoin(StablecoinPaymentMethod)

Stablecoin payment.



Crypto(CryptoPaymentMethod)

Crypto payment.



PayPal(PayPalPaymentMethod)

PayPal order.



MobileMoney(MobileMoneyPaymentMethod)

Mobile Money collection.

Implementations

Source

impl PaymentMethod

pub const fn card() -> Self

Creates a card payment method.

pub const fn paypal() -> Self

Creates a PayPal payment method.

pub fn stablecoin(asset: StablecoinAsset) -> Self

Creates a stablecoin payment method for an asset.

pub fn stablecoin_usdc() -> Self

Creates a USDC stablecoin method.

pub fn stablecoin_usdt() -> Self

Creates a USDT stablecoin method.

pub const fn crypto(asset: CryptoAsset) -> Self

Creates a crypto payment method for an asset.

pub const fn crypto_on(asset: CryptoAsset, network: CryptoNetwork) -> Self

Creates a crypto payment method for an asset on a specific network.

pub const fn usdc_on(network: CryptoNetwork) -> Self

Creates a USDC crypto payment method on a specific network.

pub const fn usdt_on(network: CryptoNetwork) -> Self

Creates a USDT crypto payment method on a specific network.

pub fn mobile_money_zambia( phone_number: impl AsRef<str>, ) -> Result<Self, PaymentError>

Creates a Zambia Mobile Money payment method.

Errors

Returns an error when the phone number or country code is invalid.