pub struct PhoneNumber(/* private fields */);Expand description
Validated E.164-style phone number.
Implementations
Sourceimpl PhoneNumber
impl PhoneNumber
Sourcepub fn new(value: impl AsRef<str>) -> Result<Self, PaymentError>
pub fn new(value: impl AsRef<str>) -> Result<Self, PaymentError>
Creates a phone number from digits with an optional leading +.
Errors
Returns an error when the phone number is outside E.164 length bounds or contains unsupported characters.
Sourcepub fn new_digits(value: impl AsRef<str>) -> Result<Self, PaymentError>
pub fn new_digits(value: impl AsRef<str>) -> Result<Self, PaymentError>
Creates a phone number without adding the display + prefix.
Errors
Returns an error when the number is invalid.